@@ -17,6 +17,8 @@ from zun.api.controllers import link
 
 _basic_keys = (
     'uuid',
+    'user_id',
+    'project_id',
     'name',
     'image',
     'links',
@@ -40,6 +42,9 @@ _basic_keys = (
     'image_driver',
     'security_groups',
     'auto_remove',
+    'runtime',
+    'hostname',
+    'disk',
 )
 
 
