@@ -13,10 +13,10 @@
 
 CONTAINER_STATUSES = (
     ERROR, RUNNING, STOPPED, PAUSED, UNKNOWN, CREATING, CREATED,
-    DELETED,
+    DELETED, DELETING
 ) = (
     'Error', 'Running', 'Stopped', 'Paused', 'Unknown', 'Creating', 'Created',
-    'Deleted',
+    'Deleted', 'Deleting'
     )
 
 TASK_STATES = (
@@ -38,3 +38,5 @@ RESOURCE_CLASSES = (
     'NUMA_SOCKET', 'NUMA_CORE', 'NUMA_THREAD', 'NUMA_MEMORY_MB',
     'IPV4_ADDRESS'
     )
+
+ALLOCATED = 'allocated'
