@@ -156,8 +156,13 @@ class DockerDriver(driver.ContainerDriver):
                 # the container's hostname
                 kwargs['hostname'] = container.hostname
 
-            runtime = container.runtime if container.runtime\
-                else CONF.container_runtime
+            if not self._is_runtime_supported():
+                if container.runtime:
+                    raise exception.ZunException(_(
+                        'Specifying runtime in Docker API is not supported'))
+                runtime = None
+            else:
+                runtime = container.runtime or CONF.container_runtime
 
             host_config = {}
             host_config['runtime'] = runtime
@@ -180,7 +185,7 @@ class DockerDriver(driver.ContainerDriver):
             if container.cpu is not None:
                 host_config['cpu_quota'] = int(100000 * container.cpu)
                 host_config['cpu_period'] = 100000
-            if container.restart_policy is not None:
+            if container.restart_policy:
                 count = int(container.restart_policy['MaximumRetryCount'])
                 name = container.restart_policy['Name']
                 host_config['restart_policy'] = {'Name': name,
@@ -203,6 +208,9 @@ class DockerDriver(driver.ContainerDriver):
             container.save(context)
             return container
 
+    def _is_runtime_supported(self):
+        return float(CONF.docker.docker_remote_api_version) >= 1.26
+
     def _process_networking_config(self, context, container,
                                    requested_networks, host_config,
                                    container_kwargs, docker):
@@ -274,21 +282,19 @@ class DockerDriver(driver.ContainerDriver):
         teardown_network = True
         if container.get_sandbox_id():
             teardown_network = False
-
         with docker_utils.docker_client() as docker:
-            if teardown_network:
-                network_api = zun_network.api(context=context,
-                                              docker_api=docker)
-                self._cleanup_network_for_container(container, network_api)
-
-            if container.container_id:
-                try:
+            try:
+                if teardown_network:
+                    network_api = zun_network.api(context=context,
+                                                  docker_api=docker)
+                    self._cleanup_network_for_container(container, network_api)
+                if container.container_id:
                     docker.remove_container(container.container_id,
                                             force=force)
-                except errors.APIError as api_error:
-                    if is_not_found(api_error):
-                        return
-                    raise
+            except errors.APIError as api_error:
+                if is_not_found(api_error):
+                    return
+                raise
 
     @wrap_docker_error
     def _cleanup_network_for_container(self, container, network_api):
@@ -470,7 +476,7 @@ class DockerDriver(driver.ContainerDriver):
             elif (state == 'created' and
                     container.status in (consts.CREATED, consts.ERROR)):
                 pass
-            elif state == 'ERROR':
+            elif state == 'paused':
                 container.status = consts.PAUSED
             elif state == 'running':
                 container.status = consts.RUNNING
@@ -638,6 +644,7 @@ class DockerDriver(driver.ContainerDriver):
         memory = patch.get('memory')
         if memory is not None:
             args['mem_limit'] = memory
+            args['memswap_limit'] = CONF.default_memory_swap
         cpu = patch.get('cpu')
         if cpu is not None:
             args['cpu_quota'] = int(100000 * cpu)
@@ -681,7 +688,7 @@ class DockerDriver(driver.ContainerDriver):
             try:
                 stream, stat = docker.get_archive(
                     container.container_id, path)
-                filedata = stream.read()
+                filedata = stream.read(decode_content=True)
                 return filedata, stat
             except errors.APIError as api_error:
                 if is_not_found(api_error):
