@@ -13,13 +13,20 @@
 from zun.objects import capsule
 from zun.objects import compute_node
 from zun.objects import container
+from zun.objects import container_action
+from zun.objects import container_pci_requests
 from zun.objects import image
 from zun.objects import numa
+from zun.objects import pci_device
+from zun.objects import pci_device_pool
 from zun.objects import resource_class
 from zun.objects import resource_provider
+from zun.objects import volume_mapping
 from zun.objects import zun_service
 
+
 Container = container.Container
+VolumeMapping = volume_mapping.VolumeMapping
 ZunService = zun_service.ZunService
 Image = image.Image
 NUMANode = numa.NUMANode
@@ -28,9 +35,16 @@ ResourceProvider = resource_provider.ResourceProvider
 ResourceClass = resource_class.ResourceClass
 ComputeNode = compute_node.ComputeNode
 Capsule = capsule.Capsule
+PciDevice = pci_device.PciDevice
+PciDevicePool = pci_device_pool.PciDevicePool
+ContainerPCIRequest = container_pci_requests.ContainerPCIRequest
+ContainerPCIRequests = container_pci_requests.ContainerPCIRequests
+ContainerAction = container_action.ContainerAction
+ContainerActionEvent = container_action.ContainerActionEvent
 
 __all__ = (
     Container,
+    VolumeMapping,
     ZunService,
     Image,
     ResourceProvider,
@@ -39,4 +53,10 @@ __all__ = (
     NUMATopology,
     ComputeNode,
     Capsule,
+    PciDevice,
+    PciDevicePool,
+    ContainerPCIRequest,
+    ContainerPCIRequests,
+    ContainerAction,
+    ContainerActionEvent,
 )
