@@ -80,33 +80,33 @@ class TestSubclassedObject(MyObj):
 
 class _TestObject(object):
     def test_hydration_type_error(self):
-        primitive = {'versioned_object.name': 'MyObj',
-                     'versioned_object.namespace': 'zun',
-                     'versioned_object.version': '1.0',
-                     'versioned_object.data': {'foo': 'a'}}
+        primitive = {'zun_object.name': 'MyObj',
+                     'zun_object.namespace': 'zun',
+                     'zun_object.version': '1.0',
+                     'zun_object.data': {'foo': 'a'}}
         self.assertRaises(ValueError, MyObj.obj_from_primitive, primitive)
 
     def test_hydration(self):
-        primitive = {'versioned_object.name': 'MyObj',
-                     'versioned_object.namespace': 'zun',
-                     'versioned_object.version': '1.0',
-                     'versioned_object.data': {'foo': 1}}
+        primitive = {'zun_object.name': 'MyObj',
+                     'zun_object.namespace': 'zun',
+                     'zun_object.version': '1.0',
+                     'zun_object.data': {'foo': 1}}
         obj = MyObj.obj_from_primitive(primitive)
         self.assertEqual(1, obj.foo)
 
     def test_hydration_bad_ns(self):
-        primitive = {'versioned_object.name': 'MyObj',
-                     'versioned_object.namespace': 'foo',
-                     'versioned_object.version': '1.0',
-                     'versioned_object.data': {'foo': 1}}
+        primitive = {'zun_object.name': 'MyObj',
+                     'zun_object.namespace': 'foo',
+                     'zun_object.version': '1.0',
+                     'zun_object.data': {'foo': 1}}
         self.assertRaises(object_exception.UnsupportedObjectError,
                           MyObj.obj_from_primitive, primitive)
 
     def test_dehydration(self):
-        expected = {'versioned_object.name': 'MyObj',
-                    'versioned_object.namespace': 'zun',
-                    'versioned_object.version': '1.0',
-                    'versioned_object.data': {'foo': 1}}
+        expected = {'zun_object.name': 'MyObj',
+                    'zun_object.namespace': 'zun',
+                    'zun_object.version': '1.0',
+                    'zun_object.data': {'foo': 1}}
         obj = MyObj(self.context)
         obj.foo = 1
         obj.obj_reset_changes()
@@ -158,12 +158,12 @@ class _TestObject(object):
         obj.foo = 1
         obj.obj_reset_changes()
         self.assertEqual('loaded!', obj.bar)
-        expected = {'versioned_object.name': 'MyObj',
-                    'versioned_object.namespace': 'zun',
-                    'versioned_object.version': '1.0',
-                    'versioned_object.changes': ['bar'],
-                    'versioned_object.data': {'foo': 1,
-                                                'bar': 'loaded!'}}
+        expected = {'zun_object.name': 'MyObj',
+                    'zun_object.namespace': 'zun',
+                    'zun_object.version': '1.0',
+                    'zun_object.changes': ['bar'],
+                    'zun_object.data': {'foo': 1,
+                                        'bar': 'loaded!'}}
         self.assertEqual(expected, obj.obj_to_primitive())
 
     def test_changes_in_primitive(self):
@@ -171,7 +171,7 @@ class _TestObject(object):
         obj.foo = 123
         self.assertEqual(set(['foo']), obj.obj_what_changed())
         primitive = obj.obj_to_primitive()
-        self.assertIn('versioned_object.changes', primitive)
+        self.assertIn('zun_object.changes', primitive)
         obj2 = MyObj.obj_from_primitive(primitive)
         self.assertEqual(set(['foo']), obj2.obj_what_changed())
         obj2.obj_reset_changes()
@@ -246,21 +246,21 @@ class _TestObject(object):
         obj = MyObj(self.context)
         obj.created_at = dt
         obj.updated_at = dt
-        expected = {'versioned_object.name': 'MyObj',
-                    'versioned_object.namespace': 'zun',
-                    'versioned_object.version': '1.0',
-                    'versioned_object.changes':
+        expected = {'zun_object.name': 'MyObj',
+                    'zun_object.namespace': 'zun',
+                    'zun_object.version': '1.0',
+                    'zun_object.changes':
                         ['created_at', 'updated_at'],
-                    'versioned_object.data':
+                    'zun_object.data':
                         {'created_at': datatime.stringify(dt),
                          'updated_at': datatime.stringify(dt)}
                     }
         actual = obj.obj_to_primitive()
-        # versioned_object.changes is built from a set and order is undefined
-        self.assertEqual(sorted(expected['versioned_object.changes']),
-                         sorted(actual['versioned_object.changes']))
-        del expected['versioned_object.changes'],\
-            actual['versioned_object.changes']
+        # zun_object.changes is built from a set and order is undefined
+        self.assertEqual(sorted(expected['zun_object.changes']),
+                         sorted(actual['zun_object.changes']))
+        del expected['zun_object.changes'],\
+            actual['zun_object.changes']
         self.assertEqual(expected, actual)
 
     def test_contains(self):
@@ -344,7 +344,8 @@ class TestObject(test_base.TestCase, _TestObject):
 # For more information on object version testing, read
 # https://docs.openstack.org/zun/latest/
 object_data = {
-    'Container': '1.18-e611f6b0fbc9f5f5c1164545b1630268',
+    'Container': '1.24-bd8b0f179b62157772955f0a76735a39',
+    'VolumeMapping': '1.1-50df6202f7846a136a91444c38eba841',
     'Image': '1.0-0b976be24f4f6ee0d526e5c981ce0633',
     'MyObj': '1.0-34c4b1aadefd177b13f9a2f894cc23cd',
     'NUMANode': '1.0-cba878b70b2f8b52f1e031b41ac13b4e',
@@ -352,8 +353,15 @@ object_data = {
     'ResourceClass': '1.1-d661c7675b3cd5b8c3618b68ba64324e',
     'ResourceProvider': '1.0-92b427359d5a4cf9ec6c72cbe630ee24',
     'ZunService': '1.1-b1549134bfd5271daec417ca8cabc77e',
-    'ComputeNode': '1.6-33a173b969781644a95ea2925eb5cca2',
-    'Capsule': '1.0-0dce1bd569773c35193d75c285226e75',
+    'Capsule': '1.5-cbdaffa78fa68c26cf4a61d8f75dd32d',
+    'PciDevice': '1.1-6e3f0851ad1cf12583e6af4df1883979',
+    'ComputeNode': '1.9-e8536102d3b28cb3378e9e26f508cd72',
+    'PciDevicePool': '1.0-3f5ddc3ff7bfa14da7f6c7e9904cc000',
+    'PciDevicePoolList': '1.0-15ecf022a68ddbb8c2a6739cfc9f8f5e',
+    'ContainerPCIRequest': '1.0-b060f9f9f734bedde79a71a4d3112ee0',
+    'ContainerPCIRequests': '1.0-7b8f7f044661fe4e24e6949c035af2c4',
+    'ContainerAction': '1.1-b0c721f9e10c6c0d1e41e512c49eb877',
+    'ContainerActionEvent': '1.0-2974d0a6f5d4821fd4e223a88c10181a'
 }
 
 
@@ -381,7 +389,7 @@ class TestObjectSerializer(test_base.TestCase):
         ser = base.ZunObjectSerializer()
         obj = MyObj(self.context)
         primitive = ser.serialize_entity(self.context, obj)
-        self.assertIn('versioned_object.name', primitive)
+        self.assertIn('zun_object.name', primitive)
         obj2 = ser.deserialize_entity(self.context, primitive)
         self.assertIsInstance(obj2, MyObj)
         self.assertEqual(self.context, obj2._context)
